@@ -113,6 +113,15 @@
 #define isnan gsl_isnan
 #endif
 
+#ifndef HAVE_LDEXP
+#define ldexp gsl_ldexp
+#endif
+
+#ifndef HAVE_FREXP
+#define frexp gsl_frexp
+#endif
+
+
 #ifndef HAVE_FINITE
 #ifdef HAVE_ISFINITE
 #define finite isfinite
@@ -127,6 +136,6 @@
 #define DISCARD_POINTER(p) /* ignoring discarded pointer */
 #endif
 
-#ifndef RANGE_CHECK_ON
-#define RANGE_CHECK_OFF  /* turn off range checking by default */
+#ifndef GSL_RANGE_CHECK_ON
+#define GSL_RANGE_CHECK_OFF  /* turn off range checking by default */
 #endif
