@@ -25,10 +25,10 @@ FUNCTION(fft_complex,pass_5) (const BASE in[],
 			      const gsl_fft_direction sign,
 			      const size_t product,
 			      const size_t n,
-			      const gsl_complex twiddle1[],
-			      const gsl_complex twiddle2[],
-			      const gsl_complex twiddle3[],
-			      const gsl_complex twiddle4[])
+			      const TYPE(gsl_complex) twiddle1[],
+			      const TYPE(gsl_complex) twiddle2[],
+			      const TYPE(gsl_complex) twiddle3[],
+			      const TYPE(gsl_complex) twiddle4[])
 {
   size_t i = 0, j = 0;
   size_t k, k1;
