@@ -25,7 +25,7 @@ FUNCTION(fft_halfcomplex,pass_n) (const BASE in[],
 				  const size_t factor,
 				  const size_t product,
 				  const size_t n,
-				  const gsl_complex twiddle[])
+				  const TYPE(gsl_complex) twiddle[])
 {
 
   size_t k, k1;
