@@ -21,6 +21,8 @@
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_histogram.h>
 
+#include "find.c"
+
 double
 gsl_histogram_get (const gsl_histogram * h, size_t i)
 {
@@ -51,3 +53,17 @@ gsl_histogram_get_range (const gsl_histogram * h, size_t i,
 
   return GSL_SUCCESS;
 }
+
+int
+gsl_histogram_find (const gsl_histogram * h,
+		    const double x, size_t * i)
+{
+  int status = find (h->n, h->range, x, i);
+
+  if (status)
+    {
+      GSL_ERROR ("x not found in range of h", GSL_EDOM);
+    }
+
+  return GSL_SUCCESS;
+}
