@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <gsl/gsl_histogram.h>
 #include <gsl/gsl_test.h>
@@ -118,7 +119,7 @@ main (void)
 
   gsl_histogram_free (h);
 
-  return gsl_test_summary ();
+  exit (gsl_test_summary ());
 }
 
 
