@@ -373,6 +373,22 @@ int gsl_linalg_solve_symm_tridiag (const gsl_vector * diag,
 				   const gsl_vector * b,
 				   gsl_vector * x);
 
+/* Linear solve for a nonsymmetric tridiagonal system.
+
+ * The input vectors represent the NxN matrix as follows:
+ *
+ *       diag[0]  abovediag[0]              0    ...
+ *  belowdiag[0]       diag[1]   abovediag[1]    ...
+ *             0  belowdiag[1]        diag[2]    ...
+ *             0             0   belowdiag[2]    ...
+ *           ...           ...            ...    ...
+ */
+int gsl_linalg_solve_tridiag (const gsl_vector * diag,
+				   const gsl_vector * abovediag,
+				   const gsl_vector * belowdiag,
+				   const gsl_vector * b,
+				   gsl_vector * x);
+
 
 /* Linear solve for a symmetric cyclic tridiagonal system.
 
@@ -390,6 +406,23 @@ int gsl_linalg_solve_symm_cyc_tridiag (const gsl_vector * diag,
 				       const gsl_vector * b,
 				       gsl_vector * x);
 
+/* Linear solve for a nonsymmetric cyclic tridiagonal system.
+
+ * The input vectors represent the NxN matrix as follows:
+ *
+ *        diag[0]  abovediag[0]             0   .....  belowdiag[N-1]
+ *   belowdiag[0]       diag[1]  abovediag[1]   .....
+ *              0  belowdiag[1]       diag[2]
+ *              0             0  belowdiag[2]   .....
+ *            ...           ...
+ * abovediag[N-1]           ...
+ */
+int gsl_linalg_solve_cyc_tridiag (const gsl_vector * diag,
+				  const gsl_vector * abovediag,
+				  const gsl_vector * belowdiag,
+				  const gsl_vector * b,
+				  gsl_vector * x);
+
 
 /* Bidiagonal decomposition */
 
