@@ -21,6 +21,7 @@
 #define __GSL_MATRIX_COMPLEX_DOUBLE_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_complex.h>
 #include <gsl/gsl_vector_complex_double.h>
@@ -210,6 +211,14 @@ int gsl_matrix_complex_transpose_memcpy (gsl_matrix_complex * dest, const gsl_ma
 
 int gsl_matrix_complex_isnull (const gsl_matrix_complex * m);
 
+int gsl_matrix_complex_add (gsl_matrix_complex * a, const gsl_matrix_complex * b);
+int gsl_matrix_complex_sub (gsl_matrix_complex * a, const gsl_matrix_complex * b);
+int gsl_matrix_complex_mul_elements (gsl_matrix_complex * a, const gsl_matrix_complex * b);
+int gsl_matrix_complex_div_elements (gsl_matrix_complex * a, const gsl_matrix_complex * b);
+int gsl_matrix_complex_scale (gsl_matrix_complex * a, const gsl_complex x);
+int gsl_matrix_complex_add_constant (gsl_matrix_complex * a, const gsl_complex x);
+int gsl_matrix_complex_add_diagonal (gsl_matrix_complex * a, const gsl_complex x);
+
 /***********************************************************************/
 /* The functions below are obsolete                                    */
 /***********************************************************************/
@@ -218,7 +227,7 @@ int gsl_matrix_complex_get_col(gsl_vector_complex * v, const gsl_matrix_complex
 int gsl_matrix_complex_set_row(gsl_matrix_complex * m, const size_t i, const gsl_vector_complex * v);
 int gsl_matrix_complex_set_col(gsl_matrix_complex * m, const size_t j, const gsl_vector_complex * v);
 
-extern int gsl_check_range ;
+GSL_VAR int gsl_check_range ;
 
 #ifdef HAVE_INLINE
 
@@ -227,9 +236,9 @@ gsl_complex
 gsl_matrix_complex_get(const gsl_matrix_complex * m, 
 		     const size_t i, const size_t j)
 {
+#ifndef GSL_RANGE_CHECK_OFF
   const gsl_complex zero = {{0,0}};
 
-#ifndef GSL_RANGE_CHECK_OFF
   if (i >= m->size1)
     {
       GSL_ERROR_VAL("first index out of range", GSL_EINVAL, zero) ;
