@@ -21,6 +21,7 @@
 #define __GSL_MATRIX_COMPLEX_FLOAT_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_complex.h>
 #include <gsl/gsl_vector_complex_float.h>
@@ -210,6 +211,14 @@ int gsl_matrix_complex_float_transpose_memcpy (gsl_matrix_complex_float * dest,
 
 int gsl_matrix_complex_float_isnull (const gsl_matrix_complex_float * m);
 
+int gsl_matrix_complex_float_add (gsl_matrix_complex_float * a, const gsl_matrix_complex_float * b);
+int gsl_matrix_complex_float_sub (gsl_matrix_complex_float * a, const gsl_matrix_complex_float * b);
+int gsl_matrix_complex_float_mul_elements (gsl_matrix_complex_float * a, const gsl_matrix_complex_float * b);
+int gsl_matrix_complex_float_div_elements (gsl_matrix_complex_float * a, const gsl_matrix_complex_float * b);
+int gsl_matrix_complex_float_scale (gsl_matrix_complex_float * a, const gsl_complex_float x);
+int gsl_matrix_complex_float_add_constant (gsl_matrix_complex_float * a, const gsl_complex_float x);
+int gsl_matrix_complex_float_add_diagonal (gsl_matrix_complex_float * a, const gsl_complex_float x);
+
 /***********************************************************************/
 /* The functions below are obsolete                                    */
 /***********************************************************************/
@@ -218,7 +227,7 @@ int gsl_matrix_complex_float_get_col(gsl_vector_complex_float * v, const gsl_mat
 int gsl_matrix_complex_float_set_row(gsl_matrix_complex_float * m, const size_t i, const gsl_vector_complex_float * v);
 int gsl_matrix_complex_float_set_col(gsl_matrix_complex_float * m, const size_t j, const gsl_vector_complex_float * v);
 
-extern int gsl_check_range ;
+GSL_VAR int gsl_check_range ;
 
 #ifdef HAVE_INLINE
 
@@ -227,9 +236,9 @@ gsl_complex_float
 gsl_matrix_complex_float_get(const gsl_matrix_complex_float * m, 
 		     const size_t i, const size_t j)
 {
+#ifndef GSL_RANGE_CHECK_OFF
   const gsl_complex_float zero = {{0,0}};
 
-#ifndef GSL_RANGE_CHECK_OFF
   if (i >= m->size1)
     {
       GSL_ERROR_VAL("first index out of range", GSL_EINVAL, zero) ;
