@@ -21,6 +21,7 @@
 #define __GSL_MATRIX_DOUBLE_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_vector_double.h>
 
@@ -202,7 +203,7 @@ int gsl_matrix_fscanf (FILE * stream, gsl_matrix * m);
 int gsl_matrix_fprintf (FILE * stream, const gsl_matrix * m, const char * format);
  
 int gsl_matrix_memcpy(gsl_matrix * dest, const gsl_matrix * src);
-int gsl_matrix_swap(gsl_matrix * m1, const gsl_matrix * m2);
+int gsl_matrix_swap(gsl_matrix * m1, gsl_matrix * m2);
 
 int gsl_matrix_swap_rows(gsl_matrix * m, const size_t i, const size_t j);
 int gsl_matrix_swap_columns(gsl_matrix * m, const size_t i, const size_t j);
@@ -226,6 +227,7 @@ int gsl_matrix_mul_elements (gsl_matrix * a, const gsl_matrix * b);
 int gsl_matrix_div_elements (gsl_matrix * a, const gsl_matrix * b);
 int gsl_matrix_scale (gsl_matrix * a, const double x);
 int gsl_matrix_add_constant (gsl_matrix * a, const double x);
+int gsl_matrix_add_diagonal (gsl_matrix * a, const double x);
 
 /***********************************************************************/
 /* The functions below are obsolete                                    */
@@ -235,7 +237,7 @@ int gsl_matrix_get_col(gsl_vector * v, const gsl_matrix * m, const size_t j);
 int gsl_matrix_set_row(gsl_matrix * m, const size_t i, const gsl_vector * v);
 int gsl_matrix_set_col(gsl_matrix * m, const size_t j, const gsl_vector * v);
 
-extern int gsl_check_range ;
+GSL_VAR int gsl_check_range ;
 
 /* inline functions if you are using GCC */
 
