@@ -21,6 +21,7 @@
 #define __GSL_MATRIX_LONG_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_vector_long.h>
 
@@ -236,7 +237,7 @@ int gsl_matrix_long_get_col(gsl_vector_long * v, const gsl_matrix_long * m, cons
 int gsl_matrix_long_set_row(gsl_matrix_long * m, const size_t i, const gsl_vector_long * v);
 int gsl_matrix_long_set_col(gsl_matrix_long * m, const size_t j, const gsl_vector_long * v);
 
-extern int gsl_check_range ;
+GSL_VAR int gsl_check_range ;
 
 /* inline functions if you are using GCC */
 
