@@ -59,7 +59,7 @@ FUNCTION (test, func) (void)
 	  };
       };
 
-    gsl_test (status, NAME (gsl_matrix) "_set writes into array correctly");
+    gsl_test (status, NAME (gsl_matrix) "_set writes into array");
   }
 
   {
@@ -74,7 +74,7 @@ FUNCTION (test, func) (void)
 	      status = 1;
 	  };
       };
-    gsl_test (status, NAME (gsl_matrix) "_get reads from array correctly");
+    gsl_test (status, NAME (gsl_matrix) "_get reads from array");
   }
 
 
@@ -108,7 +108,7 @@ FUNCTION (test, func) (void)
 	  }
       }
 
-    gsl_test (status, NAME (gsl_matrix) "_get_row extracts row correctly");
+    gsl_test (status, NAME (gsl_matrix) "_get_row extracts row");
   }
 
   {
@@ -215,7 +215,7 @@ FUNCTION (test, func) (void)
                 status = 1;
             }
         }
-      gsl_test (status, NAME (gsl_matrix) "_add adds correctly");
+      gsl_test (status, NAME (gsl_matrix) "_add matrix addition");
     }
 
 
@@ -237,7 +237,7 @@ FUNCTION (test, func) (void)
                 status = 1;
             }
         }
-      gsl_test (status, NAME (gsl_matrix) "_sub subtracts correctly");
+      gsl_test (status, NAME (gsl_matrix) "_sub matrix subtraction");
     }
 
     FUNCTION(gsl_matrix, memcpy) (m, a);
@@ -258,7 +258,7 @@ FUNCTION (test, func) (void)
                 status = 1;
             }
         }
-      gsl_test (status, NAME (gsl_matrix) "_mul_elements multiplies correctly");
+      gsl_test (status, NAME (gsl_matrix) "_mul_elements multiplication");
     }
 
     FUNCTION(gsl_matrix, memcpy) (m, a);
@@ -279,7 +279,7 @@ FUNCTION (test, func) (void)
                 status = 1;
             }
         }
-      gsl_test (status, NAME (gsl_matrix) "_div_elements divides correctly");
+      gsl_test (status, NAME (gsl_matrix) "_div_elements division");
     }
 
 
@@ -334,7 +334,7 @@ FUNCTION (test, text) (void)
 	  }
       }
 
-    gsl_test (status, NAME (gsl_matrix) "_fprintf and fscanf work correctly");
+    gsl_test (status, NAME (gsl_matrix) "_fprintf and fscanf");
 
     fclose (f);
     FUNCTION (gsl_matrix, free) (mm);
@@ -385,7 +385,7 @@ FUNCTION (test, binary) (void)
 	  }
       }
 
-    gsl_test (status, NAME (gsl_matrix) "_write and read work correctly");
+    gsl_test (status, NAME (gsl_matrix) "_write and read");
 
     fclose (f);
     FUNCTION (gsl_matrix, free) (mm);
