@@ -26,19 +26,19 @@
 #include "min.h"
 
 static int 
-compute_f_values (gsl_function * f, double minimum, double * f_minimum,
+compute_f_values (gsl_function * f, double x_minimum, double * f_minimum,
                   double x_lower, double * f_lower, 
                   double x_upper, double * f_upper);
 
 
 static int 
-compute_f_values (gsl_function * f, double minimum, double * f_minimum,
+compute_f_values (gsl_function * f, double x_minimum, double * f_minimum,
                   double x_lower, double * f_lower,
                   double x_upper, double * f_upper)
 {
   SAFE_FUNC_CALL(f, x_lower, f_lower);
   SAFE_FUNC_CALL(f, x_upper, f_upper);
-  SAFE_FUNC_CALL(f, minimum, f_minimum);
+  SAFE_FUNC_CALL(f, x_minimum, f_minimum);
 
   return GSL_SUCCESS;
 }
@@ -46,13 +46,13 @@ compute_f_values (gsl_function * f, double minimum, double * f_minimum,
 int
 gsl_min_fminimizer_set (gsl_min_fminimizer * s, 
                         gsl_function * f, 
-                        double minimum, double x_lower, double x_upper)
+                        double x_minimum, double x_lower, double x_upper)
 {
   int status ;
 
   double f_minimum, f_lower, f_upper;
 
-  status = compute_f_values (f, minimum, &f_minimum, 
+  status = compute_f_values (f, x_minimum, &f_minimum, 
                              x_lower, &f_lower,  
                              x_upper, &f_upper);
 
@@ -61,7 +61,7 @@ gsl_min_fminimizer_set (gsl_min_fminimizer * s,
       return status ;
     }
   
-  status = gsl_min_fminimizer_set_with_values (s, f, minimum, f_minimum, 
+  status = gsl_min_fminimizer_set_with_values (s, f, x_minimum, f_minimum, 
                                                x_lower, f_lower,
                                                x_upper, f_upper);
   return status;
@@ -97,12 +97,12 @@ gsl_min_fminimizer_alloc (const gsl_min_fminimizer_type * T)
 
 int
 gsl_min_fminimizer_set_with_values (gsl_min_fminimizer * s, gsl_function * f, 
-                                    double minimum, double f_minimum, 
+                                    double x_minimum, double f_minimum, 
                                     double x_lower, double f_lower,
                                     double x_upper, double f_upper)
 {
   s->function = f;
-  s->minimum = minimum;
+  s->x_minimum = x_minimum;
   s->x_lower = x_lower;
   s->x_upper = x_upper;
 
@@ -111,9 +111,9 @@ gsl_min_fminimizer_set_with_values (gsl_min_fminimizer * s, gsl_function * f,
       GSL_ERROR ("invalid interval (lower > upper)", GSL_EINVAL);
     }
 
-  if (minimum >= x_upper || minimum <= x_lower) 
+  if (x_minimum >= x_upper || x_minimum <= x_lower) 
     {
-      GSL_ERROR ("minimum must lie inside interval (lower < x < upper)",
+      GSL_ERROR ("x_minimum must lie inside interval (lower < x < upper)",
                  GSL_EINVAL);
     }
 
@@ -127,7 +127,7 @@ gsl_min_fminimizer_set_with_values (gsl_min_fminimizer * s, gsl_function * f,
     }
 
   return (s->type->set) (s->state, s->function, 
-                         minimum, f_minimum, 
+                         x_minimum, f_minimum, 
                          x_lower, f_lower,
                          x_upper, f_upper);
 }
@@ -137,7 +137,7 @@ int
 gsl_min_fminimizer_iterate (gsl_min_fminimizer * s)
 {
   return (s->type->iterate) (s->state, s->function, 
-                             &(s->minimum), &(s->f_minimum),
+                             &(s->x_minimum), &(s->f_minimum),
                              &(s->x_lower), &(s->f_lower), 
                              &(s->x_upper), &(s->f_upper));
 }
@@ -155,10 +155,17 @@ gsl_min_fminimizer_name (const gsl_min_fminimizer * s)
   return s->type->name;
 }
 
+/* Deprecated, use x_minimum instead */
 double
 gsl_min_fminimizer_minimum (const gsl_min_fminimizer * s)
 {
-  return s->minimum;
+  return s->x_minimum;
+}
+
+double
+gsl_min_fminimizer_x_minimum (const gsl_min_fminimizer * s)
+{
+  return s->x_minimum;
 }
 
 double
@@ -173,3 +180,21 @@ gsl_min_fminimizer_x_upper (const gsl_min_fminimizer * s)
   return s->x_upper;
 }
 
+double
+gsl_min_fminimizer_f_minimum (const gsl_min_fminimizer * s)
+{
+  return s->f_minimum;
+}
+
+double
+gsl_min_fminimizer_f_lower (const gsl_min_fminimizer * s)
+{
+  return s->f_lower;
+}
+
+double
+gsl_min_fminimizer_f_upper (const gsl_min_fminimizer * s)
+{
+  return s->f_upper;
+}
+
