@@ -85,7 +85,7 @@ hybrid_alloc (void *vstate, size_t n)
 
   if (J == 0)
     {
-      GSL_ERROR_VAL ("failed to allocate space for J", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for J", GSL_ENOMEM);
     }
 
   state->J = J;
@@ -96,7 +96,7 @@ hybrid_alloc (void *vstate, size_t n)
     {
       gsl_matrix_free (J);
 
-      GSL_ERROR_VAL ("failed to allocate space for q", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for q", GSL_ENOMEM);
     }
 
   state->q = q;
@@ -108,7 +108,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_matrix_free (J);
       gsl_matrix_free (q);
 
-      GSL_ERROR_VAL ("failed to allocate space for r", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for r", GSL_ENOMEM);
     }
 
   state->r = r;
@@ -121,7 +121,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_matrix_free (q);
       gsl_matrix_free (r);
 
-      GSL_ERROR_VAL ("failed to allocate space for tau", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for tau", GSL_ENOMEM);
     }
 
   state->tau = tau;
@@ -135,7 +135,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_matrix_free (r);
       gsl_vector_free (tau);
 
-      GSL_ERROR_VAL ("failed to allocate space for diag", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for diag", GSL_ENOMEM);
     }
 
   state->diag = diag;
@@ -150,7 +150,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (tau);
       gsl_vector_free (diag);
 
-      GSL_ERROR_VAL ("failed to allocate space for qtf", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for qtf", GSL_ENOMEM);
     }
 
   state->qtf = qtf;
@@ -166,7 +166,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (diag);
       gsl_vector_free (qtf);
 
-      GSL_ERROR_VAL ("failed to allocate space for newton", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for newton", GSL_ENOMEM);
     }
 
   state->newton = newton;
@@ -183,7 +183,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (qtf);
       gsl_vector_free (newton);
 
-      GSL_ERROR_VAL ("failed to allocate space for gradient", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for gradient", GSL_ENOMEM);
     }
 
   state->gradient = gradient;
@@ -201,7 +201,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (newton);
       gsl_vector_free (gradient);
 
-      GSL_ERROR_VAL ("failed to allocate space for x_trial", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for x_trial", GSL_ENOMEM);
     }
 
   state->x_trial = x_trial;
@@ -220,7 +220,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (gradient);
       gsl_vector_free (x_trial);
 
-      GSL_ERROR_VAL ("failed to allocate space for f_trial", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for f_trial", GSL_ENOMEM);
     }
 
   state->f_trial = f_trial;
@@ -240,7 +240,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (x_trial);
       gsl_vector_free (f_trial);
 
-      GSL_ERROR_VAL ("failed to allocate space for df", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for df", GSL_ENOMEM);
     }
 
   state->df = df;
@@ -261,7 +261,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (f_trial);
       gsl_vector_free (df);
 
-      GSL_ERROR_VAL ("failed to allocate space for qtdf", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for qtdf", GSL_ENOMEM);
     }
 
   state->qtdf = qtdf;
@@ -284,7 +284,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (df);
       gsl_vector_free (qtdf);
 
-      GSL_ERROR_VAL ("failed to allocate space for rdx", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for rdx", GSL_ENOMEM);
     }
 
   state->rdx = rdx;
@@ -307,7 +307,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (qtdf);
       gsl_vector_free (rdx);
 
-      GSL_ERROR_VAL ("failed to allocate space for w", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for w", GSL_ENOMEM);
     }
 
   state->w = w;
@@ -331,7 +331,7 @@ hybrid_alloc (void *vstate, size_t n)
       gsl_vector_free (rdx);
       gsl_vector_free (w);
 
-      GSL_ERROR_VAL ("failed to allocate space for v", GSL_ENOMEM, 0);
+      GSL_ERROR ("failed to allocate space for v", GSL_ENOMEM);
     }
 
   state->v = v;
