@@ -1,9 +1,28 @@
+/* poly/zsolve_quadratic.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* complex_solve_quadratic.c - finds complex roots of a x^2 + b x + c = 0 */
 
 #include <config.h>
 #include <math.h>
-#include <gsl_complex.h>
-#include <gsl_poly.h>
+#include <gsl/gsl_complex.h>
+#include <gsl/gsl_poly.h>
 
 int
 gsl_poly_complex_solve_quadratic (double a, double b, double c,
