@@ -24,7 +24,7 @@
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_sf_log.h>
 #include <gsl/gsl_sf_exp.h>
-#include "gsl_sf_gamma.h"
+#include <gsl/gsl_sf_gamma.h>
 
 #include "error.h"
 #include "check.h"
