@@ -21,6 +21,7 @@
 #define __GSL_VECTOR_DOUBLE_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_block_double.h>
 
@@ -160,7 +161,7 @@ int gsl_vector_add_constant (gsl_vector * a, const double x);
 
 int gsl_vector_isnull (const gsl_vector * v);
 
-extern int gsl_check_range;
+GSL_VAR int gsl_check_range;
 
 #ifdef HAVE_INLINE
 
